<?php

require_once 'base/GepObservacaosoliEntityBase.php';

/**
 * This class has been auto-generated by Setforms
 *
 * @package Entity
 * @author  Setforms
 */
class GepObservacaosoliEntity extends GepObservacaosoliEntityBase
{


    const SEM_REGISTRO = 10;
    const IDATIVO = 'S';


    /**  ok
     * Gera novo codigo.
     *
     * @param integer $nrorg Numero da Organizacao.
     *
     * @return Ambigous <number, number, string>
     */
    public static function novoCodigoGepObaservacaoSoli($nrorg){
        $novo_codigo = Novocodigo::geraCodigo($nrorg, 'GEP_OBSERVACAOSOLI', 10);
        return $novo_codigo;
    }


    /**   ok
     * Retorna a observacao de um parceiro de uma determinada solicitacao.
     *
     * @param integer $nrorg       Numero da organizacao.
     * @param integer $solicitacao Numero da solicitacao.
     * @param integer $parcnegocio Codigo do parceiro de negocio.
     *
     * @throws Exception Caso nao tenha nenhuma observacao.
     *
     * @return GepObservacaosoliEntity
     */
    public function retornaObservacoesSoliParceiro($nrorg, $solicitacao, $parcnegocio){
        $dados = GepObservacaosoli::consultaObservacoesSoliParceiro($nrorg, $solicitacao, $parcnegocio);

        if ($dados instanceof GepObservacaosoliEntity) {
            return $dados;
        }

        throw new Exception('GepObservacaosoliEntity: Nao ha obaservacoes para esta solicitacao.', self::SEM_REGISTRO);
    }


    /**    ok
     * Insere a observacao de alguma solicitacao.
     *
     * @param integer $codigo      Novo codigo.
     * @param integer $solicitacao Numero da solicitacao.
     * @param integer $parceiro    Codigo do parceiro.
     * @param string  $texto       Texto da observacao.
     * @param integer $nrorg       Numero da Organizacao.
     * @param date    $data        Data.
     * @param integer $operador    Operador.
     *
     * @return boolean
     */
    public function insereObservacaoSoli($codigo, $solicitacao, $parceiro, $texto, $nrorg, $data, $operador){
        try {
            $obj = new self();

            $obj->setNrobservacaosoli($codigo);
            $obj->setNrsolicitacao($solicitacao);
            $obj->setNrparcnegocio($parceiro);
            $obj->setTxobservacao($texto);
            $obj->setNrorg($nrorg);
            $obj->setIdativo(self::IDATIVO);
            $obj->setDtinclusao($data);
            $obj->setDtultatu($data);
            $obj->setNrorginclusao($nrorg);
            $obj->setCdoperinclusao($operador);
            $obj->setNrorgultatu($nrorg);
            $obj->setCdoperultatu($operador);
            $obj->persist();

            return true;
        } catch (Exception $e) {
            showClassError($e, __FUNCTION__, __LINE__);
            return false;
        }
    }


    /**
     * Atualiza uma determinada observação de um operador ou geral.
     *
     * @param string  $strSql_parceiro String da query se filtrara a consulta com o parceiro de negocio null ou não.
     * @param integer $nrorg           Número da Organização.
     * @param integer $solicitacao     Número da Solicitação.
     * @param string  $observacao      Observação.
     * @param date    $data            Data.
     * @param integer $operador        Operador.
     *
     * @return boolean
     */
    public function atualizaObservacaoSoli(
        $strSql_parceiro, $nrorg, $solicitacao, $observacao, $data, $operador
    ) {
        try {
            $where = 'NRORG = ? AND NRSOLICITACAO = ? AND '.$strSql_parceiro;

            $lista_observacoes = GepObservacaosoli::getObjectsByWhere(
                $where,
                array(
                 $nrorg,
                 $solicitacao,
                )
            );

            foreach ($lista_observacoes as $obj) {
                $obj->setTxobservacao($observacao);
                $obj->setDtultatu($data);
                $obj->setNrorgultatu($nrorg);
                $obj->setCdoperultatu($operador);

                $obj->persist();
            }

            return true;
        } catch (Exception $e) {
            showClassError($e, __FUNCTION__, __LINE__);
            return false;
        }
    }


    /**       ok
     * Retorna a consulta de uma observacao geral da solicitacao determinada.
     *
     * @param integer $nrorg       Numero da organizacao.
     * @param integer $solicitacao Numero da solicitacao.
     *
     * @throws Exception Se nao houver dados.
     *
     * @return GepObservacaosoliEntity
     */
    public function retornaObservacaoGeralSoli($nrorg, $solicitacao){
        $dados = GepObservacaosoli::consultaObservacaoGeralSoli($nrorg, $solicitacao);

        if ($dados instanceof GepObservacaosoliEntity) {
            return $dados;
        }

        throw new Exception(
            'GepObservacaosoliEntity: Nao ha obaservacao geral para esta solicitacao.',
            self::SEM_REGISTRO
        );
    }


    /**
     * Atualiza o valor da cor de uma observacao de um determinado parceiro e solicitacao.
     *
     * @param integer $nrorg       Numero da organizacao.
     * @param integer $parceiro    Numero do parceiro.
     * @param integer $solicitacao Numero da solicitacao.
     * @param string  $fonte       Codigo RGB da fonte.
     *
     * @return boolean
     */
    public function atualizaCorFonteObservSoli(
            $nrorg, $parceiro, $solicitacao, $fonte
    ) {
        try {
            $where = 'NRORG = ? AND NRPARCNEGOCIO = ? AND NRSOLICITACAO = ?';

            $observacao = GepObservacaosoli::getObjectsByWhere(
                $where,
                array(
                 $nrorg,
                 $parceiro,
                 $solicitacao,
                )
            );

            foreach ($observacao as $obj) {
                $obj->setDsatributofonte($fonte);
                $obj->persist();

            }


            return true;
        } catch (Exception $e) {
            showClassError($e, __FUNCTION__, __LINE__);
            return false;
        }
    }


}