function Est70000_ResumoDeOperacoes_Controller(General, ZhLayoutPreferences, localStorageEngine, metaDataFactory, ScreenService, EstUtil, ZhFilterPreferences, templateManager, Est70000_ResumoDeOperacoes_Service) {

    let IDUTILALMOX, IDUTILLCESTQ;

    this.onOpenFilter = function(widget) {
        let rowsToSet = {};
        const actualDate = getLocalVar('DTPROCESSA');

        rowsToSet.INTERVALO = { "start": actualDate, "end": actualDate, "formattedStart": actualDate, "formattedEnd": actualDate };
        rowsToSet.NMFILIAL = getLocalVar('NMFILIAL');
        rowsToSet.CDFILIAL = getLocalVar('CDFILIAL');

        ZhFilterPreferences.openFilterWidget(widget, rowsToSet).then(success => {
            const filterWidget = templateManager.container.getActiveWidget('zhFilterPreferencesSelectConditions');

            filterWidget.getField('NMFILIAL').reload().then(_ => {
                this.onChangeUnity(filterWidget);
            });
        });
    };

    this.onManageFilterParams = function(widget) {
        const filter = [
            {
                "name": "CDFILIAL",
                "operator": "=",
                "value": EstUtil.getFieldValue('CDFILIAL', 'mainWidget', true)
            },
            {
                "name": "CDALMOXARIFE",
                "operator": "=",
                "value": EstUtil.getFieldValue('CDALMOXARIFE', 'mainWidget', true) || ' '
            },
            {
                "name": "CDLOCALESTOQ",
                "operator": "=",
                "value": EstUtil.getFieldValue('CDLOCALESTOQ', 'mainWidget', true) || ' '
            },
            {
                "name": "CDGRUPPROD",
                "operator": "=",
                "value": EstUtil.getFieldValue('CDGRUPPROD', 'mainWidget', true)
            },
            {
                "name": "DTINICIAL",
                "operator": "=",
                "value": EstUtil.getFieldValue('INTERVALO', 'mainWidget', true).start
            },
            {
                "name": "DTFINAL",
                "operator": "=",
                "value": EstUtil.getFieldValue('INTERVALO', 'mainWidget', true).end
            }
        ];

        General.callRestEngine('est_relatorios#/get_resumo_operacoes', 'FilterData', filter).then(result => {
            localStorageEngine.setDataSource('/get_resumo_operacoes', result.dataset.get_resumo_operacoes).then(_ => {
                this.clearResults(widget);
                localStorageEngine.getDataSource('/get_resumo_operacoes').then(result => {
                    widget.dataSource.data = result;
                    this.onShowFields(widget);
                });
            });
        });
    };

    this.onChangeUnity = function(widget) {
        Est70000_ResumoDeOperacoes_Service.getUnityInfo(widget.currentRow.CDFILIAL).then(data => {
            const {
                IDUTILALMOX: CTRLALMOX,
                IDUTILLCESTQ: CTRLLOCAL
            } = data.dataset.paramfilial[0];
            const almoxField = widget.getField('DSALMOXARIFE');
            const LocalField = widget.getField('DSLOCALESTOQ');

            IDUTILALMOX = CTRLALMOX == 'S' ? true : false;
            IDUTILLCESTQ = CTRLLOCAL == 'S' ? true : false;

            almoxField.clearValue();

            if (IDUTILALMOX) {
                almoxField.readOnly = false;
                almoxField.validations = { "required": { "message": "Campo Obrigatório" } };
                if (IDUTILLCESTQ) {
                    LocalField.readOnly = false;
                    LocalField.validations = { "required": { "message": "Campo Obrigatório" } };
                }
            }
            else {
                delete almoxField.validations;
                almoxField.readOnly = true;
                almoxField.clearValue();
            }
            almoxField.reload();
            this.onChangeAlmox(widget);
        });
    };

    this.onChangeAlmox = function(widget) {
        const LocalField = widget.getField('DSLOCALESTOQ');

        if (IDUTILLCESTQ && widget.currentRow.CDALMOXARIFE) {
            LocalField.validations = { "required": { "message": "Campo Obrigatório" } };
            LocalField.readOnly = false;
            LocalField.clearValue();
        }
        else {
            LocalField.setValue(' ');
            widget.currentRow.CDLOCALESTOQ = ' ';
            delete LocalField.validations;
            LocalField.readOnly = true;
        }
        LocalField.reload();
        templateManager.updateTemplate();
    };

    this.onShowFields = function(widget) {
        const results = widget.dataSource.data;

        ZhLayoutPreferences.applyOriginalLayout(widget);
        if (results instanceof Array) {
            const cdgrupprod = EstUtil.getFieldValue('CDGRUPPROD', 'mainWidget', true);

            Est70000_ResumoDeOperacoes_Service.getfieldsLabels(cdgrupprod).then(success => {
                const originalLabels = ["TITLE", "TOTAL"];
                const exceptionsFields = ["__isSelected", "__is_new"];

                for (var object in results[0]) {
                    this.createField(widget, object, success.dataset.subgrupprod, originalLabels, exceptionsFields);
                    if (object == "TOTAL")
                        widget.redraw();
                }
            });
        }
    };

    this.createField = function(widget, name, groups, originalLabels, exceptionsFields) {
        if (exceptionsFields.includes(name)) return;

        let field;
        let label = originalLabels.includes(name) ? name : groups.filter(gp => gp.CDSUBGRPROD == name)[0].NMSUBGRPROD;

        if (name === "TITLE") {
            field = {
                "name": name,
                "label": " ",
                "showOnForm": true,
                "showOnView": true,
                "showOnList": true,
                "readOnly": true,
                "template": "field/text-edit.html"
            };
        }
        else {
            field = {
                "name": name,
                "label": ScreenService.i18n(label),
                "showOnForm": true,
                "showOnView": true,
                "showOnList": true,
                "readOnly": true,
                "template": "field/text-edit.html",
                "align": "right",
                "filterProperties": {
                    "isVisible": false,
                    "showOnForm": false
                },
                "mask": {
                    "type": "float",
                    "params": {
                        "showSymbol": false,
                        "precision": 2,
                        "thousands": ".",
                        "decimal": ","
                    }
                }
            };
        }

        metaDataFactory.factoryField(field, widget, true);
    };

    this.clearResults = function(widget) {

        const originalFields = [
            "CDFILIAL",
            "NMFILIAL",
            "CDALMOXARIFE",
            "DSALMOXARIFE",
            "CDLOCALESTOQ",
            "DSLOCALESTOQ",
            "CDGRUPPROD",
            "NMGRUPPROD",
            "INTERVALO"
        ];

        widget.fields = widget.fields.filter(field => {
            return originalFields.includes(field.name);
        });
        widget.dataSource.data = [];
    };

    this.changeRowStyles = function(row) {
        const totalizationTitles = [
            "Ticket's Caixa",
            "Quantidade Ticket's Caixa",
            "Quantidade Itens",
            "Ticket's Médio",
            "Itens P/T.C"
        ];

        return totalizationTitles.includes(row.TITLE) ? true : false;
    };

    this.resetCustomFilter = function(args) {
        args.e.preference.CUSTOM_FILTER_ROW = {};
    };
}

Configuration(function(ContextRegister) {
    ContextRegister.register('Est70000_ResumoDeOperacoes_Controller', Est70000_ResumoDeOperacoes_Controller);
});
